@@ -10,7 +10,6 @@ import (
 	"time"
 
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/vul"
 	batchv1 "k8s.io/api/batch/v1"
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -29,7 +28,7 @@ func (Job) Header(ns string) Header {
 	h := Header{
 		HeaderColumn{Name: "NAMESPACE"},
 		HeaderColumn{Name: "NAME"},
-		HeaderColumn{Name: "VS"},
+		HeaderColumn{Name: "VS", VS: true},
 		HeaderColumn{Name: "COMPLETIONS"},
 		HeaderColumn{Name: "DURATION"},
 		HeaderColumn{Name: "SELECTOR", Wide: true},
@@ -38,9 +37,6 @@ func (Job) Header(ns string) Header {
 		HeaderColumn{Name: "VALID", Wide: true},
 		HeaderColumn{Name: "AGE", Time: true},
 	}
-	if vul.ImgScanner == nil {
-		h = append(h[:vulIdx], h[vulIdx+1:]...)
-	}
 
 	return h
 }
@@ -64,7 +60,7 @@ func (j Job) Render(o interface{}, ns string, r *Row) error {
 	r.Fields = Fields{
 		job.Namespace,
 		job.Name,
-		computeVulScore(&job.Spec.Template.Spec),
+		computeVulScore(job.ObjectMeta, &job.Spec.Template.Spec),
 		ready,
 		toDuration(job.Status),
 		jobSelector(job.Spec),
@@ -73,9 +69,6 @@ func (j Job) Render(o interface{}, ns string, r *Row) error {
 		AsStatus(j.diagnose(ready, job.Status.CompletionTime)),
 		ToAge(job.GetCreationTimestamp()),
 	}
-	if vul.ImgScanner == nil {
-		r.Fields = append(r.Fields[:vulIdx], r.Fields[vulIdx+1:]...)
-	}
 
 	return nil
 }
