@@ -6,13 +6,13 @@ package ui_test
 import (
 	"testing"
 
-	"github.com/derailed/k9s/internal/config"
+	"github.com/derailed/k9s/internal/config/mock"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/stretchr/testify/assert"
 )
 
 func TestAppGetCmd(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 	a.CmdBuff().SetText("blee", "")
 
@@ -20,7 +20,7 @@ func TestAppGetCmd(t *testing.T) {
 }
 
 func TestAppInCmdMode(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 	a.CmdBuff().SetText("blee", "")
 	assert.False(t, a.InCmdMode())
@@ -30,7 +30,7 @@ func TestAppInCmdMode(t *testing.T) {
 }
 
 func TestAppResetCmd(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 	a.CmdBuff().SetText("blee", "")
 
@@ -40,7 +40,7 @@ func TestAppResetCmd(t *testing.T) {
 }
 
 func TestAppHasCmd(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 
 	a.ActivateCmd(true)
@@ -51,7 +51,7 @@ func TestAppHasCmd(t *testing.T) {
 }
 
 func TestAppGetActions(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 
 	a.AddActions(ui.KeyActions{ui.KeyZ: ui.KeyAction{Description: "zorg"}})
@@ -60,7 +60,7 @@ func TestAppGetActions(t *testing.T) {
 }
 
 func TestAppViews(t *testing.T) {
-	a := ui.NewApp(config.NewConfig(nil), "")
+	a := ui.NewApp(mock.NewMockConfig(), "")
 	a.Init()
 
 	vv := []string{"crumbs", "logo", "prompt", "menu"}
