@@ -12,6 +12,7 @@ import (
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/config"
 	"github.com/derailed/k9s/internal/render"
+	"github.com/derailed/k9s/internal/view/cmd"
 	"github.com/rs/zerolog/log"
 	"github.com/sahilm/fuzzy"
 )
@@ -24,10 +25,10 @@ const (
 	SearchFmt = "<[filter:bg:r]/%s[fg:bg:-]> "
 
 	// NSTitleFmt represents a namespaced view title.
-	NSTitleFmt = "[fg:bg:b] %s([hilite:bg:b]%s[fg:bg:-])[fg:bg:-][[count:bg:b]%d[fg:bg:-]][fg:bg:-] "
+	NSTitleFmt = "[fg:bg:b] %s([hilite:bg:b]%s[fg:bg:-])[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
 
 	// TitleFmt represents a standard view title.
-	TitleFmt = "[fg:bg:b] %s[fg:bg:-][[count:bg:b]%d[fg:bg:-]][fg:bg:-] "
+	TitleFmt = "[fg:bg:b] %s[fg:bg:-][[count:bg:b]%s[fg:bg:-]][fg:bg:-] "
 
 	descIndicator = "↓"
 	ascIndicator  = "↑"
@@ -41,11 +42,9 @@ const (
 
 var (
 	// LabelRx identifies a label query.
-	LabelRx = regexp.MustCompile(`\A\-l`)
-
+	LabelRx   = regexp.MustCompile(`\A\-l`)
 	inverseRx = regexp.MustCompile(`\A\!`)
-
-	fuzzyRx = regexp.MustCompile(`\A\-f`)
+	fuzzyRx   = regexp.MustCompile(`\A\-f`)
 )
 
 func mustExtractStyles(ctx context.Context) *config.Styles {
@@ -71,7 +70,11 @@ func IsLabelSelector(s string) bool {
 	if s == "" {
 		return false
 	}
-	return LabelRx.MatchString(s)
+	if LabelRx.MatchString(s) {
+		return true
+	}
+
+	return !strings.Contains(s, " ") && cmd.ToLabels(s) != nil
 }
 
 // IsFuzzySelector checks if query is fuzzy.
@@ -92,7 +95,19 @@ func IsInverseSelector(s string) bool {
 
 // TrimLabelSelector extracts label query.
 func TrimLabelSelector(s string) string {
-	return strings.TrimSpace(s[2:])
+	if strings.Index(s, "-l") == 0 {
+		return strings.TrimSpace(s[2:])
+	}
+
+	return s
+}
+
+func truncate(s string, max int) string {
+	if len(s) < max {
+		return s
+	}
+
+	return s[:max] + "..."
 }
 
 // SkinTitle decorates a title.
