@@ -57,6 +57,9 @@ type Tabular interface {
 	// SetLabelFilter sets the label filter.
 	SetLabelFilter(string)
 
+	// GetLabelFilter fetch the label filter.
+	GetLabelFilter() string
+
 	// Empty returns true if model has no data.
 	Empty() bool
 
