@@ -12,6 +12,7 @@ import (
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/dao"
 	"github.com/derailed/k9s/internal/model"
+	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/derailed/k9s/internal/xray"
 	"github.com/derailed/tcell/v2"
@@ -24,7 +25,7 @@ import (
 
 var _ ResourceViewer = (*Sanitizer)(nil)
 
-// Sanitizer represents an sanitizer tree view.
+// Sanitizer represents a sanitizer tree view.
 type Sanitizer struct {
 	*ui.Tree
 
@@ -46,6 +47,9 @@ func NewSanitizer(gvr client.GVR) ResourceViewer {
 	}
 }
 
+func (s *Sanitizer) SetFilter(string)                 {}
+func (s *Sanitizer) SetLabelFilter(map[string]string) {}
+
 // Init initializes the view.
 func (s *Sanitizer) Init(ctx context.Context) error {
 	s.envFn = s.k9sEnv
@@ -96,7 +100,7 @@ func (*Sanitizer) InCmdMode() bool {
 
 // ExtraHints returns additional hints.
 func (s *Sanitizer) ExtraHints() map[string]string {
-	if s.app.Config.K9s.NoIcons {
+	if s.app.Config.K9s.UI.NoIcons {
 		return nil
 	}
 	return xray.EmojiInfo()
@@ -266,7 +270,7 @@ func (s *Sanitizer) TreeLoadFailed(err error) {
 }
 
 func (s *Sanitizer) update(node *xray.TreeNode) {
-	root := makeTreeNode(node, s.ExpandNodes(), s.app.Config.K9s.NoIcons, s.app.Styles)
+	root := makeTreeNode(node, s.ExpandNodes(), s.app.Config.K9s.UI.NoIcons, s.app.Styles)
 	if node == nil {
 		s.app.QueueUpdateDraw(func() {
 			s.SetRoot(root)
@@ -313,7 +317,7 @@ func (s *Sanitizer) TreeChanged(node *xray.TreeNode) {
 }
 
 func (s *Sanitizer) hydrate(parent *tview.TreeNode, n *xray.TreeNode) {
-	node := makeTreeNode(n, s.ExpandNodes(), s.app.Config.K9s.NoIcons, s.app.Styles)
+	node := makeTreeNode(n, s.ExpandNodes(), s.app.Config.K9s.UI.NoIcons, s.app.Styles)
 	for _, c := range n.Children {
 		s.hydrate(node, c)
 	}
@@ -414,9 +418,9 @@ func (s *Sanitizer) styleTitle() string {
 
 	var title string
 	if ns == client.ClusterScope {
-		title = ui.SkinTitle(fmt.Sprintf(ui.TitleFmt, base, s.Count), s.app.Styles.Frame())
+		title = ui.SkinTitle(fmt.Sprintf(ui.TitleFmt, base, render.AsThousands(int64(s.Count))), s.app.Styles.Frame())
 	} else {
-		title = ui.SkinTitle(fmt.Sprintf(ui.NSTitleFmt, base, ns, s.Count), s.app.Styles.Frame())
+		title = ui.SkinTitle(fmt.Sprintf(ui.NSTitleFmt, base, ns, render.AsThousands(int64(s.Count))), s.app.Styles.Frame())
 	}
 
 	buff := s.CmdBuff().GetText()
